@@ -4,7 +4,7 @@ import os, sys
 from twisted.internet import reactor, defer
 from twisted.python import log
 from twisted.application import service
-from foolscap import Tub, eventual
+from foolscap.api import Tub, fireEventually
 
 MB = 1000000
 
@@ -26,7 +26,7 @@ class SpeedTest:
 
     def run(self):
         print "STARTING"
-        d = eventual.fireEventually()
+        d = fireEventually()
         d.addCallback(lambda res: self.setUp())
         d.addCallback(lambda res: self.do_test())
         d.addBoth(self.tearDown)
@@ -48,6 +48,7 @@ class SpeedTest:
     def setUp(self):
         self.base_service.startService()
         self.tub = Tub()
+        self.tub.setOption("expose-remote-exception-types", False)
         self.tub.setServiceParent(self.base_service)
         d = self.tub.getReference(self.control_furl)
         def _gotref(rref):
