@@ -154,11 +154,18 @@ _platform_map = {
     "irix6-n64": "irix",
     "irix6": "irix",
     "openbsd2": "bsd",
+    "openbsd3": "bsd",
+    "openbsd4": "bsd",
     "darwin": "bsd",       # Mac OS X
     "freebsd4": "bsd",
     "freebsd5": "bsd",
     "freebsd6": "bsd",
     "netbsd1": "bsd",
+    "netbsd2": "bsd",
+    "netbsd3": "bsd",
+    "netbsd4": "bsd",
+    "netbsd5": "bsd",
+    "netbsd6": "bsd",
     "sunos5": "sunos",
     "cygwin": "cygwin",
     }
